.. This is part of the Photini documentation.
   Copyright (C)  2012-17  Jim Easterbrook.
   See the file ../DOC_LICENSE.txt for copying condidions.

GNU Free Documentation License
==============================

The Photini documentation is licensed under the GNU Free Documentation License.

.. literalinclude:: ../DOC_LICENSE.txt
   :language: none
